@@ -79,7 +79,7 @@ densityMap<-function(trees,res=100,fsize=NULL,ftype=NULL,lwd=3,check=FALSE,legen
 
 ## S3 plot method for objects of class "densityMap"
 ## also used internally by plot.contMap
-## written by Liam J. Revell 2012, 2013, 2014, 2015
+## written by Liam J. Revell 2012, 2013, 2014, 2015, 2016
 
 plot.densityMap<-function(x,...){
 	if(class(x)=="densityMap"){
@@ -110,6 +110,8 @@ plot.densityMap<-function(x,...){
 	else direction<-"rightwards"
 	if(hasArg(offset)) offset<-list(...)$offset
 	else offset<-NULL
+	if(hasArg(xlim)) xlim<-list(...)$xlim
+	else xlim<-NULL
 	if(hasArg(ylim)) ylim<-list(...)$ylim
 	else ylim<-NULL
 	if(hasArg(hold)) hold<-list(...)$hold
@@ -134,12 +136,12 @@ plot.densityMap<-function(x,...){
 		if(outline){
 			par(col="transparent")
 			plotTree(tree,fsize=fsize[1],lwd=lwd[1]+2,
-				offset=offset+0.2*lwd[1]/3+0.2/3,ftype=ftype[1],
+				offset=offset+0.2*lwd[1]/3+0.2/3,ftype=ftype[1],xlim=xlim,
 				ylim=ylim,mar=mar,direction=direction,hold=FALSE)
 			par(col="black")
 		}
 		plotSimmap(tree,cols,pts=FALSE,lwd=lwd[1],fsize=fsize[1],mar=mar,ftype=ftype[1],add=outline,
-			ylim=ylim,direction=direction,offset=offset,hold=FALSE)
+			xlim=xlim,ylim=ylim,direction=direction,offset=offset,hold=FALSE)
 		if(legend){
 			ff<-function(dd){
 				if(!("."%in%dd)) dig<-0
@@ -149,19 +151,19 @@ plot.densityMap<-function(x,...){
 			dig<-max(sapply(strsplit(leg.txt[c(1,3)],split=""),ff))
 			add.color.bar(legend,cols,title=leg.txt[2],lims<-as.numeric(leg.txt[c(1,3)]),
 				digits=dig,prompt=FALSE,x=0,y=1-0.08*(N-1),lwd=lwd[2],
-				fsize=fsize[2])
+				fsize=fsize[2],direction=direction)
 		}
 	} else if(type=="fan"){
 		if(outline){
 			par(col="white")
 			invisible(capture.output(plotTree(tree,type="fan",lwd=lwd[1]+2,
 				mar=mar,fsize=fsize[1],
-				ftype=ftype[1],ylim=ylim,hold=FALSE)))
+				ftype=ftype[1],xlim=xlim,ylim=ylim,hold=FALSE)))
 			par(col="black")
 		}
 		invisible(capture.output(plotSimmap(tree,cols,lwd=lwd[1],
 			mar=mar,fsize=fsize[1],add=outline,ftype=ftype[1],
-			type="fan",ylim=ylim,hold=FALSE)))
+			type="fan",xlim=xlim,ylim=ylim,hold=FALSE)))
 		if(legend){
 			ff<-function(dd){
 				if(!("."%in%dd)) dig<-0
